@@ -1,9 +1,17 @@
 import os
 
-__version__ = '0.8.4'
-__license__  = 'MIT'
+__version__ = '0.9.0'
+__license__ = 'MIT'
 __author__ = 'Steven Loria'
 
 PACKAGE_DIR = os.path.dirname(os.path.abspath(__file__))
 
 from .blob import TextBlob, Word, Sentence, Blobber, WordList
+
+__all__ = [
+    'TextBlob',
+    'Word',
+    'Sentence',
+    'Blobber',
+    'WordList',
+]
