@@ -10,3 +10,8 @@ is equivalent to
 '''
 from __future__ import absolute_import
 from textblob.en.inflect import singularize, pluralize
+
+__all__ = [
+    'singularize',
+    'pluralize',
+]
