@@ -1,18 +1,20 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Translator module that uses the Google Translate API.
 
 Adapted from Terry Yin's google-translate-python.
 Language detection added by Steven Loria.
-'''
+"""
 from __future__ import absolute_import
 import re
+import codecs
 from textblob.compat import PY2, request, urlencode
+from textblob.exceptions import TranslatorError
 
 
 class Translator(object):
 
-    '''A language translator and detector.
+    """A language translator and detector.
 
     Usage:
     ::
@@ -22,7 +24,7 @@ class Translator(object):
         u'bonjour'
         >>> t.detect("hola")
         u'es'
-    '''
+    """
 
     string_pattern = r"\"(([^\"\\]|\\.)*)\""
     translation_pattern = re.compile(
@@ -31,9 +33,9 @@ class Translator(object):
                            + string_pattern + r"\,"
                            + string_pattern + r"\,"
                            + string_pattern
-                        +r"\]")
+                        + r"\]")
     detection_pattern = re.compile(
-            r".*?\,\"([a-z]{2}(\-\w{2})?)\"\,.*?", flags=re.S)
+        r".*?\,\"([a-z]{2}(\-\w{2})?)\"\,.*?", flags=re.S)
 
     url = "http://translate.google.com/translate_a/t"
 
@@ -41,7 +43,7 @@ class Translator(object):
             'AppleWebKit/535.19 (KHTML, like Gecko) Chrome/18.0.1025.168 Safari/535.19')}
 
     def translate(self, source, from_lang='en', to_lang='en', host=None, type_=None):
-        '''Translate the source text from one language to another.'''
+        """Translate the source text from one language to another."""
         if PY2:
             source = source.encode('utf-8')
         data = {"client": "t", "ie": "UTF-8", "oe": "UTF-8",
@@ -50,9 +52,11 @@ class Translator(object):
         return self._get_translation_from_json5(json5)
 
     def detect(self, source, host=None, type_=None):
-        '''Detect the source text's language.'''
+        """Detect the source text's language."""
         if PY2:
             source = source.encode('utf-8')
+        if len(source) < 3:
+            raise TranslatorError('Must provide a string with at least 3 characters.')
         data = {"client": "t", "ie": "UTF-8", "oe": "UTF-8", "text": source}
         json5 = self._get_json5(self.url, host=host, type_=type_, data=data)
         lang = self._get_language_from_json5(json5)
@@ -65,7 +69,7 @@ class Translator(object):
         return match.group(1)
 
     def _get_translation_from_json5(self, content):
-        result = ""
+        result = u""
         pos = 2
         while True:
             m = self.translation_pattern.match(content, pos)
@@ -73,16 +77,21 @@ class Translator(object):
                 break
             result += m.group(1)
             pos = m.end()
-        return self._unescape(result)
+        return _unescape(result)
 
     def _get_json5(self, url, host=None, type_=None, data=None):
-        encoded_data = urlencode(data).encode("utf-8")
+        encoded_data = urlencode(data).encode('utf-8')
         req = request.Request(url=url, headers=self.headers, data=encoded_data)
         if host or type_:
             req.set_proxy(host=host, type=type_)
-        r = request.urlopen(req)
-        content = r.read()
+        resp = request.urlopen(req)
+        content = resp.read()
         return content.decode('utf-8')
 
-    def _unescape(self, text):
-        return re.sub(r"\\.?", lambda x:eval('"%s"'%x.group(0)), text)
+
+def _unescape(text):
+    """Unescape unicode character codes within a string.
+    """
+    pattern = r'\\{1,2}u[0-9a-fA-F]{4}'
+    decode = lambda x: codecs.getdecoder('unicode_escape')(x.group())[0]
+    return re.sub(pattern, decode, text)
